@@ -12,6 +12,8 @@ from aspectlib.test import record
 class Base(object):
     def meth(*_):
         return 'base'
+
+
 Base2 = Base
 
 
@@ -21,11 +23,15 @@ class Sub(Base):
 
 class Global(Base):
     pass
+
+
 Global2 = Global
 
 
 class MissingGlobal(Base):
     pass
+
+
 AliasedGlobal = MissingGlobal
 del MissingGlobal
 
@@ -36,6 +42,8 @@ def module_func():
 
 def module_func2():
     pass
+
+
 module_func3 = module_func2
 
 
@@ -322,7 +330,7 @@ def test_aspect_raise():
 
     @aspect
     def func():
-        1/0
+        1 / 0
 
     assert func() == 'stuff'
 
@@ -330,7 +338,7 @@ def test_aspect_raise():
 def test_aspect_raise_from_aspect():
     @aspectlib.Aspect
     def aspect():
-        1/0
+        1 / 0
         yield
 
     @aspect
@@ -417,6 +425,15 @@ def test_weave_str_class_meth_target():
     assert Stuff().meth() is None
 
 
+def test_weave_old_style_method_no_warn_patch_module():
+    calls = []
+    with aspectlib.weave('warnings.warn', record(calls=calls)):
+        with aspectlib.weave('test_aspectlib.LegacyTestClass.foobar', mock('stuff')):
+            assert LegacyTestClass().foobar() == 'stuff'
+
+    assert calls == []
+
+
 def test_weave_wrong_module():
     calls = []
     with aspectlib.weave('warnings.warn', record(calls=calls)):
@@ -428,6 +445,7 @@ def test_weave_wrong_module():
          {})
     ]
 
+
 def test_weave_no_aliases():
     with aspectlib.weave(module_func2, mock('stuff'), aliases=False):
         assert module_func2() == 'stuff'
@@ -560,7 +578,7 @@ def test_weave_subclass_meth_from_baseclass():
     def aspect(*args):
         result = yield
         history.append(args + (result,))
-        yield aspectlib.Return('bar-'+result)
+        yield aspectlib.Return('bar-' + result)
 
     with aspectlib.weave(NormalTestSubClass.only_in_base, aspect):
         inst = NormalTestSubClass('stuff')
@@ -580,7 +598,7 @@ def test_weave_subclass_meth_from_baseclass_2_level():
     def aspect(*args):
         result = yield
         history.append(args + (result,))
-        yield aspectlib.Return('bar-'+result)
+        yield aspectlib.Return('bar-' + result)
 
     with aspectlib.weave(NormalTestSubSubClass.only_in_base, aspect):
         inst = NormalTestSubSubClass('stuff')
@@ -600,7 +618,7 @@ def test_weave_legacy_subclass_meth_from_baseclass():
     def aspect(*args):
         result = yield
         history.append(args + (result,))
-        yield aspectlib.Return('bar-'+result)
+        yield aspectlib.Return('bar-' + result)
 
     with aspectlib.weave(LegacyTestSubClass.only_in_base, aspect):
         inst = LegacyTestSubClass('stuff')
@@ -620,7 +638,7 @@ def test_weave_legacy_subclass_meth_from_baseclass_2_level():
     def aspect(*args):
         result = yield
         history.append(args + (result,))
-        yield aspectlib.Return('bar-'+result)
+        yield aspectlib.Return('bar-' + result)
 
     with aspectlib.weave(LegacyTestSubSubClass.only_in_base, aspect):
         inst = LegacyTestSubSubClass('stuff')
@@ -858,7 +876,6 @@ def test_weave_class_on_init():
 
     inst = SlotsTestClass()
     with aspectlib.weave(SlotsTestClass, aspect, lazy=True):
-
         inst = SlotsTestClass('stuff')
         assert inst.foo == 'stuff'
         assert inst.bar is None
@@ -1137,7 +1154,7 @@ def test_just_proceed_with_error():
 
     @aspect
     def func():
-        1/0
+        1 / 0
 
     raises(ZeroDivisionError, func)
 
@@ -1172,6 +1189,7 @@ def test_weave_subclass_meth_manual():
 
     assert Sub().meth() == 'base'
 
+
 @pytest.mark.skipif('aspectlib.PY3')
 def test_weave_subclass_meth_auto():
     with aspectlib.weave(Sub.meth, mock('foobar'), lazy=True):
@@ -1179,6 +1197,7 @@ def test_weave_subclass_meth_auto():
 
     assert Sub().meth() == 'base'
 
+
 @pytest.mark.skipif('aspectlib.PY2')
 def test_weave_subclass_meth_auto2():
     with aspectlib.weave(Sub.meth, mock('foobar')):
@@ -1207,6 +1226,7 @@ def test_sentinel():
 def _internal():
     pass
 
+
 if aspectlib.PY3:
     exec(u"""# encoding: utf8
 
@@ -1278,13 +1298,12 @@ def test_aspect_on_func():
     @aspect
     def func():
         raise RuntimeError()
+
     assert func() == 'squelched'
     assert hist == ['before', 'error', 'finally', 'closed']
 
 
 def test_aspect_on_func_invalid_advice():
-    hist = []
-
     @aspectlib.Aspect
     def aspect():
         yield "stuff"
@@ -1295,6 +1314,7 @@ def test_aspect_on_func_invalid_advice():
 
     raises(aspectlib.UnacceptableAdvice, func)
 
+
 def test_aspect_on_generator_func():
     hist = []
 
@@ -1322,8 +1342,9 @@ def test_aspect_on_generator_func():
         for i in range(3):
             yield i
         raise RuntimeError()
+
     assert list(func()) == [0, 1, 2]
-    print (hist)
+    print(hist)
     assert hist == ['before', 'error', 'finally', 'closed']
 
 
@@ -1353,25 +1374,9 @@ def test_aspect_on_generator_different_args():
     assert list(func()) == ['something']
 
 
-def test_aspect_on_generator_raise_stopiteration():
-    result = []
-
-    @aspectlib.Aspect
-    def aspect():
-        val = yield aspectlib.Proceed
-        result.append(val)
-
-    @aspect
-    def func():
-        raise StopIteration('something')
-        yield
-
-    assert list(func()) == []
-    assert result == ['something']
-
-
 def test_aspect_on_generator_close():
     excs = []
+
     @aspectlib.Aspect
     def aspect():
         yield aspectlib.Proceed
@@ -1395,6 +1400,7 @@ def test_aspect_on_generator_close():
 
 def test_aspect_on_generator_throw():
     excs = []
+
     @aspectlib.Aspect
     def aspect():
         yield aspectlib.Proceed
@@ -1418,6 +1424,7 @@ def test_aspect_on_generator_throw():
 
 def test_aspect_on_generator_throw_exhaust():
     excs = []
+
     @aspectlib.Aspect
     def aspect():
         yield aspectlib.Proceed
@@ -1461,85 +1468,6 @@ def test_aspect_on_generator_send_in_aspect():
     assert values == [1, 3]
 
 
-def test_aspect_on_generator_result_from_aspect():
-    @aspectlib.Aspect
-    def aspect():
-        yield aspectlib.Proceed
-        yield aspectlib.Return('result')
-
-    @aspect
-    def func():
-        yield 'something'
-
-    gen = func()
-    try:
-        while 1:
-            next(gen)
-    except StopIteration as exc:
-        assert exc.args == ('result',)
-    else:
-        raise AssertionError("did not raise StopIteration")
-
-
-def test_aspect_on_generator_result():
-    result = []
-    @aspectlib.Aspect
-    def aspect():
-        result.append((yield aspectlib.Proceed))
-
-    @aspect
-    def func():
-        yield 'something'
-        raise StopIteration('value')
-
-    assert list(func()) == ['something']
-    assert result == ['value']
-
-
-def test_aspect_on_coroutine():
-    hist = []
-
-    @aspectlib.Aspect
-    def aspect():
-        try:
-            hist.append('before')
-            hist.append((yield aspectlib.Proceed))
-            hist.append('after')
-        except Exception:
-            hist.append('error')
-        finally:
-            hist.append('finally')
-        try:
-            hist.append((yield aspectlib.Return))
-        except GeneratorExit:
-            hist.append('closed')
-            raise
-        else:
-            hist.append('consumed')
-        hist.append('bad-suffix')
-
-    @aspect
-    def func():
-        val = 99
-        for _ in range(3):
-            print("YIELD", val + 1)
-            val = yield val + 1
-            print("GOT", val)
-        raise StopIteration("the-return-value")
-    gen = func()
-    data = []
-    try:
-        for i in [None, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9]:
-            data.append(gen.send(i))
-    except StopIteration:
-        data.append('done')
-    print(data)
-    assert data == [100, 1, 2, 'done'], hist
-    print (hist)
-    assert hist == ['before', 'the-return-value', 'after', 'finally', 'closed']
-
-
-
 def test_weave_module(strmod=None):
     calls = []
     from test_pkg1.test_pkg2 import test_mod
@@ -1552,5 +1480,56 @@ def test_weave_module(strmod=None):
         (obj, 'test_pkg1.test_pkg2.test_mod.meth', (), {})
     ]
 
+
 def test_weave_module_as_str():
     test_weave_module("test_pkg1.test_pkg2.test_mod")
+
+
+def test_weave_method():
+    calls = []
+    intercepted = []
+
+    @aspectlib.Aspect(bind=True)
+    def intercept(func, *args):
+        intercepted.append(args)
+        yield aspectlib.Proceed(*args)
+
+    class Foo(object):
+        def foo(self, arg):
+            calls.append((self, arg))
+
+    f = Foo()
+    with aspectlib.weave(f.foo, intercept):
+        f.foo(1)
+
+    assert calls == [(f, 1)]
+    assert intercepted == [(f, 1)]
+
+
+def test_weave_method_noargs():
+    calls = []
+    intercepted = []
+
+    @aspectlib.Aspect(bind=True)
+    def intercept(func, *args):
+        intercepted.append(args)
+        yield
+
+    class Foo(object):
+        def foo(self, arg):
+            calls.append((self, arg))
+
+    f = Foo()
+    with aspectlib.weave(f.foo, intercept):
+        f.foo(1)
+
+    assert calls == [(f, 1)]
+    assert intercepted == [(f, 1)]
+
+
+def test_weave_debug_log():
+    from aspectlib.contrib import retry
+    from aspectlib.debug import log
+
+    with aspectlib.weave(log, retry):
+        pass
